# This function is for decadal-daily data loading.
# The time input (leadtimemin & leadtimemax) units in the recipe is month. For example, leadtimemin = 0 means the first month, and leadtimemax = 2 means the 3rd month.
# For daily data, if initial month is November, leadtimemin = 0 equals to c(1:30), and leadtimemax = 2, which means January next year, equals to c(31+31:31+31+30).
get_daily_time_ind <- function(leadtimemin, leadtimemax, initial_month, sdates, calendar) {
  #TODO: calendar & leap year
  # E.g., time = 1:4 means Dec to March, then indices will be c(31:(31+30+31+28+31)) for non-leap yr and c(31:(31+30+31+28), (31+30+31+28+2):(31+30+31+28+2+30)) for leap yr. Calendar needs to be considered too.

  if (!calendar %in% c('360-day', '365_day', 'noleap', 'standard', 'proleptic_gregorian',
                       'gregorian')) 
    stop("The calendar is not recognized. Please contact maintainers.")

  total_months <- (initial_month + leadtimemin):(initial_month + leadtimemax)
  total_months <- ifelse(total_months > 12, total_months %% 12, total_months)
  total_months <- ifelse(total_months == 0, 12, total_months)

  if (calendar == '360-day') {
    daily_time_ind <- 1:(30 * length(total_months))

  } else {
    leap <- leap_year(sdates)

    if (all(!leap) | calendar %in% c('365_day', 'noleap')) {
      total_days_sum <- sum(days_in_month(total_months))
      if (leadtimemin == 0) {
        daily_time_ind <- 1:total_days_sum    
      } else {
        before_start_months <- initial_month:(initial_month + leadtimemin - 1)
        before_start_months <- ifelse(before_start_months > 12, before_start_months %% 12, before_start_months)
        before_start_months <- ifelse(before_start_months == 0, 12, before_start_months)
        before_start_total_days_sum <- sum(days_in_month(before_start_months))
        daily_time_ind <- (before_start_total_days_sum + 1):(before_start_total_days_sum + total_days_sum)
      }

    } else if (calendar %in% c('standard', 'proleptic_gregorian', 'gregorian')) {

  
    }
  }

  return(daily_time_ind)
}
